@@ -1,5 +1,5 @@
 ## data_fun.R | ds4psy
-## hn | uni.kn | 2020 05 06
+## hn | uni.kn | 2020 05 17
 ## ---------------------------
 
 ## Functions for creating and manipulating data. 
@@ -25,7 +25,7 @@ random_bin_value <- function(x = c(0, 1), n = 1, replace = TRUE) {
 
 
 
-# Coin flip: Flip a fair coin n times (with events): ------ 
+# coin: Flip a fair coin n times (with events): ------ 
 
 #' Flip a fair coin (with 2 sides "H" and "T") n times. 
 #'
@@ -60,7 +60,7 @@ random_bin_value <- function(x = c(0, 1), n = 1, replace = TRUE) {
 #' coin(3, events = NA)
 #' coin(NULL, NULL)
 #' 
-#' @family random functions
+#' @family sampling functions
 #'
 #' @export 
 
@@ -130,14 +130,136 @@ coin <- function(n = 1, events = c("H", "T")){
 # hist(r_s, right = TRUE)
 # hist(r_s, right = FALSE)
 
+
+# Sample random characters (from given characters): ------ 
+
+#' Draw a sample of n random characters 
+#' (from given characters). 
+#'
+#' \code{sample_char} draws a sample of  
+#' \code{n} random characters from a given range of characters.
+#' 
+#' By default, \code{sample_char} draws \code{n = 1} 
+#' a random alphabetic character from  
+#' \code{x_char = c(letters, LETTERS)}.
+#' 
+#' As with \code{sample()}, the sample size \code{n} must not exceed 
+#' the number of available characters \code{nchar(x_char)}, 
+#' unless \code{replace = TRUE} (i.e., sampling with replacement). 
+#' 
+#' @param x_char Population of characters to sample from. 
+#' Default: \code{x_char = c(letters, LETTERS)}. 
+#' 
+#' @param n Number of characters to draw. 
+#' Default: \code{n = 1}. 
+#' 
+#' @param replace Boolean: Sample with replacement? 
+#' Default: \code{replace = FALSE}. 
+#' 
+#' @param ... Other arguments.  
+#' (Use for specifying \code{prob}, as passed to \code{sample()}.)   
+#' 
+#' @examples
+#' sample_char()  # default
+#' sample_char(n = 10)
+#' sample_char(x_char = "abc", n = 10, replace = TRUE)
+#' sample_char(x_char = c("x y", "6 9"), n =  6, replace = FALSE)
+#' sample_char(x_char = c("x y", "6 9"), n = 20, replace = TRUE)
+#' 
+#' # Biased sampling: 
+#' sample_char(x_char = "abc", n = 20, replace = TRUE, 
+#'              prob = c(3/6, 2/6, 1/6))
+#' 
+#' # Note: By default, n must not exceed nchar(x_char):
+#' sample_char(n = 52, replace = FALSE)    # works, but
+#' # sample_char(n = 53, replace = FALSE)  # would yield ERROR; 
+#' sample_char(n = 53, replace = TRUE)     # works again.
+#' 
+#' @family sampling functions
+#'
+#' @export 
+
+sample_char <- function(x_char = c(letters, LETTERS), n = 1, replace = FALSE, ...){
+  
+  out <- NA  # initialize
+  
+  # Checks: 
+  # x_char is a vector of characters:
+  if (!is.character(x_char)){
+    message("sample_char: x_char must be of type character.")
+  }
+  
+  # # x_char is not "":
+  # if ((all(is.character(x_char))) & (sum(nchar(x_char) == 0))){
+  #   message("sample_char: x_char must contain at least 1 character.")
+  # }
+  
+  # Split x_char into a vector of individual characters:
+  char_v <- unlist(strsplit(x_char, split = ""))
+  
+  # Check: Verify that is something to sample from:   
+  if (length(char_v) == 0){
+    message("sample_char: x_char must contain at least 1 character.")
+  }
+  
+  # Use sample(): 
+  sample_v <- sample(x = char_v, size = n, replace = replace, ...)
+  
+  # Paste into single char:
+  out <- paste0(sample_v, collapse = "")
+  
+  return(out)
+  
+} # sample_char end. 
+
+# ## Check: 
+# sample_char()
+# sample_char(n = 10)
+# sample_char(x_char = "abc", n = 10, replace = TRUE)
+# sample_char(x_char = c("x y", "6 9"), n =  6, replace = FALSE)
+# sample_char(x_char = c("x y", "6 9"), n = 20, replace = TRUE)
+# 
+# # Biased sampling: 
+# sample_char(x_char = "abc", n = 20, replace = TRUE, prob = c(3/6, 2/6, 1/6))
+#
+# # Note: By default, n must not exceed nchar(x_char):
+# sample_char(n = 52, replace = FALSE)    # works, but
+# # sample_char(n = 53, replace = FALSE)  # yields ERROR.
+# sample_char(n = 53, replace = TRUE)     # works again
+
+# ## Errors:
+#
+# sample_char(x_char = 1)
+# sample_char(x_char = NA)
+# sample_char(x_char = NULL)
+#
+# sample_char(x_char = "")
+# sample_char(x_char = c("", ""))
+# sample_char(x_char = c("", "", " "))
+
+# ## R meta-characters:
+# metas <- c(". \ | ( ) [ { ^ $ * + ?")
+# nomta <- c(", : / < > ] } & % # - ! =")
+# 
+# # without spaces:
+# mcv <- unlist(strsplit(metas, split = " "))
+# mcv  # Note: \ is now ""!
+# nmv <- unlist(strsplit(nomta, split = " "))
+# nmv
+# 
+# # Apply: 
+# sample_char(x_char = c(mcv, nmv), n = 24, replace = FALSE)  # unique items
+# sample_char(x_char = c(mcv, nmv), n = 50, replace = TRUE)   # repeated items
+
+
 # Sample random dates (from a given range): ------
 
 #' Draw a sample of n random dates (from a given range). 
 #'
-#' \code{sample_dates} draws a sample of  
+#' \code{sample_date} draws a sample of  
 #' \code{n} random dates from a given range.
 #' 
-#' By default, \code{sample_dates} draws \code{n = 1} 
+#' By default, \code{sample_date} draws \code{n = 1} 
 #' random date in the range 
 #' \code{from = "1970-01-01"} 
 #' \code{to = Sys.Date()} (current date).
@@ -152,19 +274,19 @@ coin <- function(n = 1, events = c("H", "T")){
 #' Default: \code{to = Sys.Date()}. 
 #' 
 #' @examples
-#' sample_dates()
-#' sort(sample_dates(n = 10))
-#' sort(sample_dates(n = 10, from = "2020-02-28", to = "2020-03-01"))  # 2020 is a leap year
+#' sample_date()
+#' sort(sample_date(n = 10))
+#' sort(sample_date(n = 10, from = "2020-02-28", to = "2020-03-01"))  # 2020 is a leap year
 #' 
 #' # Note: Oddity with sample():
-#' sort(sample_dates(n = 10, from = "2020-01-01", to = "2020-01-01"))  # range of 0!
+#' sort(sample_date(n = 10, from = "2020-01-01", to = "2020-01-01"))  # range of 0!
 #' # see sample(9:9, size = 10, replace = TRUE)
 #' 
-#' @family random functions
+#' @family sampling functions
 #'
 #' @export 
 
-sample_dates <- function(n = 1, from = "1970-01-01", to = Sys.Date()){
+sample_date <- function(n = 1, from = "1970-01-01", to = Sys.Date()){
   
   # set.seed(1984)  # for reproducible randomness
   d1 <- as.Date(from)  
@@ -176,12 +298,12 @@ sample_dates <- function(n = 1, from = "1970-01-01", to = Sys.Date()){
 }
 
 ## Check:
-# sample_dates()
-# sort(sample_dates(n = 10))
-# sort(sample_dates(n = 10, from = "2020-02-28", to = "2020-03-01"))  # 2020 is a leap year
+# sample_date()
+# sort(sample_date(n = 10))
+# sort(sample_date(n = 10, from = "2020-02-28", to = "2020-03-01"))  # 2020 is a leap year
 # 
 # # Note: Oddity with sample():
-# sort(sample_dates(n = 10, from = "2020-01-01", to = "2020-01-01"))  # range of 0!
+# sort(sample_date(n = 10, from = "2020-01-01", to = "2020-01-01"))  # range of 0!
 # # see sample(9:9, size = 10, replace = TRUE)
 
 
@@ -189,10 +311,10 @@ sample_dates <- function(n = 1, from = "1970-01-01", to = Sys.Date()){
 
 #' Draw a sample of n random times (from a given range). 
 #'
-#' \code{sample_times} draws a sample of  
+#' \code{sample_time} draws a sample of  
 #' \code{n} random times from a given range.
 #' 
-#' By default, \code{sample_times} draws \code{n = 1} 
+#' By default, \code{sample_time} draws \code{n = 1} 
 #' random time in the range 
 #' \code{from = "1970-01-01 00:00:00"} 
 #' \code{to = Sys.time()} (current time).
@@ -208,27 +330,27 @@ sample_dates <- function(n = 1, from = "1970-01-01", to = Sys.Date()){
 #' 
 #' @examples
 #' # Basics:
-#' sample_times()
-#' sample_times(n = 10)
+#' sample_time()
+#' sample_time(n = 10)
 #' 
 #' # Specific ranges:
-#' sort(sample_times(n = 10, from = (Sys.time() - 60)))  # within the last minute
-#' sort(sample_times(n = 10, from = (Sys.time() - 1 * 60 * 60)))  # within the last hour
-#' sort(sample_times(n = 10, from = Sys.time(), 
-#'                             to = (Sys.time() + 1 * 60 * 60)))  # within the next hour
-#' sort(sample_times(n = 10, from = "2020-01-01 00:00:00 CET", 
-#'                             to = "2020-01-01 00:00:01 CET"))  # within 1 sec range
+#' sort(sample_time(n = 10, from = (Sys.time() - 60)))  # within the last minute
+#' sort(sample_time(n = 10, from = (Sys.time() - 1 * 60 * 60)))  # within the last hour
+#' sort(sample_time(n = 10, from = Sys.time(), 
+#'                            to = (Sys.time() + 1 * 60 * 60)))  # within the next hour
+#' sort(sample_time(n = 10, from = "2020-01-01 00:00:00 CET", 
+#'                            to = "2020-01-01 00:00:01 CET"))  # within 1 sec range
 #'  
 #' # Note: Oddity with sample(): 
-#' sort(sample_times(n = 10, from = "2020-01-01 00:00:00 CET", 
-#'                             to = "2020-01-01 00:00:00 CET"))  # range of 0!
+#' sort(sample_time(n = 10, from = "2020-01-01 00:00:00 CET", 
+#'                            to = "2020-01-01 00:00:00 CET"))  # range of 0!
 #' # see sample(9:9, size = 10, replace = TRUE)
 #' 
-#' @family random functions
+#' @family sampling functions
 #'
 #' @export
 
-sample_times <- function(n = 1, from = "1970-01-01 00:00:00", to = Sys.time()){
+sample_time <- function(n = 1, from = "1970-01-01 00:00:00", to = Sys.time()){
   
   t1 <- as.POSIXlt(from)
   t2 <- as.POSIXlt(to)
@@ -240,17 +362,17 @@ sample_times <- function(n = 1, from = "1970-01-01 00:00:00", to = Sys.time()){
 
 # ## Check:
 # # Basics:
-# sample_times()
-# sample_times(n = 10)
+# sample_time()
+# sample_time(n = 10)
 # 
 # # Specific ranges:
-# sort(sample_times(n = 10, from = (Sys.time() - 60)))  # within the last minute
-# sort(sample_times(n = 10, from = (Sys.time() - 1 * 60 * 60)))  # within the last hour
-# sort(sample_times(n = 10, from = Sys.time(), to = (Sys.time() + 1 * 60 * 60)))  # within the next hour
-# sort(sample_times(n = 10, from = "2020-01-01 00:00:00 CET", to = "2020-01-01 00:00:01 CET"))  # within 1 sec range
+# sort(sample_time(n = 10, from = (Sys.time() - 60)))  # within the last minute
+# sort(sample_time(n = 10, from = (Sys.time() - 1 * 60 * 60)))  # within the last hour
+# sort(sample_time(n = 10, from = Sys.time(), to = (Sys.time() + 1 * 60 * 60)))  # within next hour
+# sort(sample_time(n = 10, from = "2020-01-01 00:00:00 CET", to = "2020-01-01 00:00:01 CET"))  # 1 sec range
 # 
 # # Note: Oddity with sample():
-# sort(sample_times(n = 10, from = "2020-01-01 00:00:00 CET", to = "2020-01-01 00:00:00 CET"))  # range of 0!
+# sort(sample_time(n = 10, from = "2020-01-01 00:00:00 CET", to = "2020-01-01 00:00:00 CET"))  # range of 0!
 # # see sample(9:9, size = 10, replace = TRUE)
 
 ## Note: Sampling normally distributed times:
@@ -309,7 +431,7 @@ sample_times <- function(n = 1, from = "1970-01-01 00:00:00", to = Sys.time()){
 #' dice(5, events = 1/2)
 #' dice(NULL, NULL)
 #' 
-#' @family random functions
+#' @family sampling functions
 #'
 #' @export 
 
@@ -427,7 +549,7 @@ dice <- function(n = 1, events = 1:6){
 #' dice_2(n = 10, sides = 9:9)  # odd: see sample() for an explanation.
 #' 
 #' 
-#' @family random functions
+#' @family sampling functions
 #'
 #' @export 
 
@@ -645,6 +767,7 @@ add_whats <- function(vec, amount, what = NA){
 # add_whats(1:10, .5, what = "ABC")
 
 
+
 ## (2) Make tables for plots: ----------
 
 # make_tb: Create (n x n) table tb for plots: --------
@@ -811,8 +934,6 @@ make_tbs <- function(n = NA, rseed = NA){
 #'
 #' @family data functions
 #'
-#' 
-#' 
 #' @export 
 
 make_grid <- function(x_min = 0, x_max = 2, y_min = 0, y_max = 1){
